@@ -11,7 +11,7 @@ use vars qw(@EXPORT @EXPORT_OK @ISA $VERSION);
 BEGIN {
     require Exporter;
     @ISA = qw(Exporter);
-    $VERSION = '1.06';
+    $VERSION = '1.07';
     @EXPORT = @EXPORT_OK = qw(rd_f wr_f ap_f find_home find_temp find_bin lockafile unlockafile unlock_all_the_files);
 }
 
@@ -100,7 +100,7 @@ sub rd_f {
         return undef;
     }
     $! = 0;
-    unless (open($fh, '< :raw :bytes', $fn)) {
+    unless (open($fh, '< :raw', $fn)) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', "cannot open for reading", $!, 0+$!);
         return undef;
     }
@@ -144,7 +144,7 @@ sub wr_f {
         return undef;
     }
     $! = 0;
-    unless (open($fh, '> :raw :bytes', $fn)) {
+    unless (open($fh, '> :raw', $fn)) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', "cannot open for writing", $!, 0+$!);
         return undef;
     }
@@ -171,7 +171,7 @@ sub ap_f {
         return undef;
     }
     $! = 0;
-    unless (open($fh, '>> :raw :bytes', $fn)) {
+    unless (open($fh, '>> :raw', $fn)) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', "cannot open for appending", $!, 0+$!);
         return undef;
     }
